@@ -36,8 +36,12 @@
       (funcall func (get-buffer-create case:folder))
       (mew-set-buffer-cs mew-cs-m17n)
       (mew-buffers-setup case:folder)
-      (mew-sinfo-set-case (mew-case:folder-case case:folder))
-      (mew-sinfo-set-folder (mew-case:folder-folder case:folder))
+      (let* ((case (mew-case:folder-case case:folder))
+	     (folder (mew-case:folder-folder case:folder))
+	     (inboxp (string= folder (mew-proto-inbox-folder folder (or case mew-case)))))
+	(mew-sinfo-set-case case)
+	(mew-sinfo-set-folder folder)
+	(mew-sinfo-set-inboxp inboxp))
       (if (mew-folder-virtualp case:folder)
 	  (progn
 	    (if p-folder (mew-vinfo-set-parent-folder p-folder))
@@ -75,11 +79,13 @@ Summary mode."
 	(setq sep (mew-imap-separator case))
 	(unless (or (assoc folder folder-alist)
 		    (assoc (concat folder sep) folder-alist))
-	  (message "%s does not exist" case:folder)
+	  (message "\"%s\" does not exist. %s" case:folder
+		   (mew-substitute-for-summary "Type '3\\[mew-status-update]' to collect IMAP folders"))
 	  (setq case:folder nil)))
        ((mew-folder-nntpp folder)
 	(unless (assoc folder (mew-nntp-folder-alist case))
-	  (message "%s does not exist" case:folder)
+	  (message "\"%s\" does not exist. %s" case:folder
+		   (mew-substitute-for-summary "Type '2\\[mew-status-update]' to collect newsgroups"))
 	  (setq case:folder nil))))
       (when case:folder
 	(when mew-use-other-frame-for-summary
@@ -146,13 +152,10 @@ If 'mew-summary-goto-line-then-display' is non-nil,
 the message is then displayed."
   (interactive "P")
   (if arg
-      (let ((msg (read-string "Message No.: " "")) regex)
+      (let ((msg (read-string "Message No.: " "")))
 	(while (not (string-match mew-regex-message-files3 msg))
 	  (setq msg (read-string "Message No.: " "")))
-	(setq regex (mew-regex-sumsyn-msg msg))
-	(when (or (re-search-forward regex nil t)
-		  (re-search-backward regex nil t))
-	  (beginning-of-line)
+	(when (mew-summary-search-msg msg)
 	  (if mew-summary-goto-line-then-display
 	      (mew-summary-display))))
     (let ((line (string-to-number (read-string "Line No.: " ""))))
@@ -183,15 +186,18 @@ the message is then displayed."
 ;;;
 
 (defun mew-max-draft-buffer ()
-  (let* ((regex (mew-folder-regex (file-name-as-directory mew-draft-folder)))
-	 (bufs (mew-buffer-list regex))
-	 buf draft)
-    (while bufs
-      (setq buf (car bufs))
-      (setq bufs (cdr bufs))
-      (if (or (null draft) (string< draft buf))
-	  (setq draft buf)))
-    draft))
+  (let* ((draft-dir (file-name-as-directory mew-draft-folder))
+	 (regex (mew-folder-regex draft-dir))
+         (bufs (mew-buffer-list regex))
+	 (msgregex (format "\\([0-9]+\\)\\(%s\\)?$" mew-suffix))
+         nums num n)
+    (setq nums (mapcar (lambda (x) (string-match msgregex x) (string-to-number (mew-match-string 1 x))) bufs))
+    (while nums
+      (setq num (car nums))
+      (setq nums (cdr nums))
+      (if (or (null n) (< n num))
+	  (setq n num)))
+    (and n (format "%s%d%s" draft-dir n (if mew-use-suffix mew-suffix "")))))
 
 (defun mew-summary-jump-to-draft-buffer ()
   "Jump to one of drafts if exists."
@@ -364,7 +370,7 @@ argument."
   (mew-summary-msg-or-part
    (let* ((fld (mew-summary-folder-name))
 	  (msg (mew-summary-message-number))
-	  (file (mew-expand-folder fld msg))
+	  (file (mew-expand-msg fld msg))
 	  (cmd-args (mew-input-command))
 	  (cmd (car cmd-args)) 
 	  (args (nconc (cdr cmd-args) (list file))))
@@ -430,8 +436,8 @@ Content-Type is automatically asked. And if it has both
 internal and external visualization mechanisms, you are asked
 which you want to use.
 
-If executed with'\\[universal-argument]', you can specify a command
-to be executed.
+If executed with '\\[universal-argument]', you can specify a
+command to be executed.
 
 See 'mew-mime-content-type' to know how actions can be defined."
   (interactive "P")
@@ -607,7 +613,7 @@ If executed with '\\[universal-argument]', you can set the sending case."
 	   (proto (mew-proto-to-flush fld))
 	   qfld case)
       (if (or arg mew-ask-flush-case)
-	  (setq case (mew-input-case mew-case"Queue"))
+	  (setq case (mew-input-case mew-case "Queue"))
 	(setq case mew-case))
       (if (or (mew-folder-queuep fld) (mew-folder-postqp fld))
 	  (progn
@@ -778,6 +784,7 @@ message."
 	 (mew-erase-buffer)
 	 (call-process mew-prog-mewl nil t nil
 		       "-b" mew-mail-path "-l" "0"
+		       "-x" mew-suffix
 		       "-i" tfile "-d" "content-type")
 	 (mew-delete-file tfile)
 	 (goto-char (point-min))
@@ -826,7 +833,7 @@ message."
 	  (goto-char (point-max))
 	  (save-restriction
 	    (narrow-to-region (point) (point))
-	    (mew-insert-file-contents (mew-expand-folder cfld (aref vec 0)))
+	    (mew-insert-file-contents (mew-expand-msg cfld (aref vec 0)))
 	    ;; Removing unnecessary fields from the encapsulating
 	    ;; (outer) header.
 	    (goto-char (point-min))
@@ -859,7 +866,7 @@ message."
 	    (goto-char (point-max))
 	    (save-restriction
 	      (narrow-to-region (point) (point))
-	      (mew-insert-file-contents (mew-expand-folder cfld (aref vec i)))
+	      (mew-insert-file-contents (mew-expand-msg cfld (aref vec i)))
 	      (goto-char (point-min))
 	      (re-search-forward mew-eoh nil t)
 	      (forward-line)
@@ -929,11 +936,11 @@ message."
      (save-excursion
        (mew-summary-goto-message)
        (setq msg (mew-summary-message-number)))
-     (setq file (mew-expand-folder fld msg))
+     (setq file (mew-expand-msg fld msg))
      (setq dstfld (mew-input-local-folder mew-inbox-folder))
      (when (and dstfld (mew-local-folder-check dstfld 'ask))
        (setq dstmsg (mew-folder-new-message dstfld 'numonly))
-       (setq dstfile (mew-expand-folder dstfld dstmsg))
+       (setq dstfile (mew-expand-msg dstfld dstmsg))
        (when (get-buffer dstfld)
 	 (set-buffer dstfld)
 	 (setq exclusivep (mew-summary-exclusive-p)))
@@ -985,8 +992,8 @@ the region are handled."
 	 (setq total (length msgs))
 	 (setq i 1)
 	 (while msgs
-	   (setq file (mew-expand-folder fld (car msgs)))
-	   (setq dstfile (mew-expand-folder dstfld dstmsg))
+	   (setq file (mew-expand-msg fld (car msgs)))
+	   (setq dstfile (mew-expand-new-msg dstfld dstmsg))
 	   (message "Copying (%d/%d)..." i total)
 	   (mew-summary-local-copy-one file dstfile)
 	   (setq dstmsg (number-to-string (1+ (string-to-number dstmsg))))
@@ -1232,7 +1239,7 @@ See also 'mew-spam-prog' and 'mew-spam-prog-args."
   (mew-summary-msg
    (let* ((fld (mew-summary-folder-name))
 	  (msg (mew-summary-message-number))
-	  (file (mew-expand-folder fld msg))
+	  (file (mew-expand-msg fld msg))
 	  (case (mew-sinfo-get-case))
 	  (prog (mew-spam-prog case))
 	  (args (mew-spam-prog-args case))
@@ -1256,7 +1263,7 @@ See also 'mew-ham-prog' and 'mew-ham-prog-args."
   (mew-summary-msg
    (let* ((fld (mew-summary-folder-name))
 	  (msg (mew-summary-message-number))
-	  (file (mew-expand-folder fld msg))
+	  (file (mew-expand-msg fld msg))
 	  (case (mew-sinfo-get-case))
 	  (prog (mew-ham-prog case))
 	  (args (mew-ham-prog-args case))
@@ -1289,7 +1296,7 @@ See also 'mew-ham-prog' and 'mew-ham-prog-args."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1996-2005 Mew developing team.
+;; Copyright (C) 1996-2006 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
